@@ -20,24 +20,28 @@
 #ifndef KSNIP_SAVEPATHPROVIDER_H
 #define KSNIP_SAVEPATHPROVIDER_H
 
-#include "src/backend/saver/WildcardResolver.h"
-#include "src/backend/saver/UniqueNameProvider.h"
-#include "src/backend/config/KsnipConfigProvider.h"
+#include <QSharedPointer>
 
-class SavePathProvider
+#include "ISavePathProvider.h"
+#include "src/backend/saver/WildcardResolver.h"
+#include "src/backend/saver/NameProvider.h"
+#include "src/backend/saver/UniqueNameProvider.h"
+#include "src/backend/config/IConfig.h"
+
+class SavePathProvider : public ISavePathProvider
 {
 public:
-    SavePathProvider();
-    ~SavePathProvider() = default;
-    QString savePath() const;
-    QString savePathWithFormat(const QString& format) const;
-    QString saveDirectory() const;
+	explicit SavePathProvider(const QSharedPointer<IConfig> &config);
+	~SavePathProvider() = default;
+	QString savePath() const override;
+	QString savePathWithFormat(const QString& format) const override;
+	QString saveDirectory() const override;
 
 private:
-    KsnipConfig *mConfig;
+	QSharedPointer<IConfig> mConfig;
 
-    QString getFormat(const QString &format) const;
-    QString getFilename() const;
+	QString getFormat(const QString &format) const;
+	QString getFilename() const;
 };
 
 #endif //KSNIP_SAVEPATHPROVIDER_H
