@@ -20,8 +20,6 @@
 
 #include "MainWindow.h"
 
-#include <QDebug>
-
 MainWindow::MainWindow(DependencyInjector *dependencyInjector) :
 	QMainWindow(),
 	mDependencyInjector(dependencyInjector),
@@ -63,7 +61,7 @@ MainWindow::MainWindow(DependencyInjector *dependencyInjector) :
 	mClipboard(mDependencyInjector->get<IClipboard>()),
 	mCapturePrinter(new CapturePrinter(this)),
 	mGlobalHotKeyHandler(new GlobalHotKeyHandler(mImageGrabber->supportedCaptureModes(), mDependencyInjector->get<IPlatformChecker>(), mConfig)),
-	mDragAndDropProcessor(new DragAndDropProcessor(this)),
+	mDragAndDropProcessor(new DragAndDropProcessor(this, mDependencyInjector->get<ITempFileProvider>())),
 	mUploadHandler(mDependencyInjector->get<IUploadHandler>()),
 	mSessionManagerRequestedQuit(false),
 	mResizeOnNormalize(false),
@@ -638,7 +636,7 @@ void MainWindow::showOpenImageDialog()
 {
 	auto title = tr("Open Images");
 	auto directory = mSavePathProvider->saveDirectory();
-	auto filter = tr("Image Files") + FileDialogFilters::ImageFiles;
+	auto filter = tr("Image Files") + FileDialogFilterHelper::ImageFilesImport();
 	auto pathList = mFileDialogService->getOpenFileNames(this, title, directory, filter);
 
 	for (const auto &path : pathList) {
