@@ -25,16 +25,17 @@
 #include <QDesktopServices>
 #include <QUrl>
 
-#include "IToastService.h"
-#include "src/backend/config/KsnipConfigProvider.h"
+#include "INotificationService.h"
+#include "src/backend/config/IConfig.h"
 #include "src/common/enum/CaptureModes.h"
-#include "src/common/loader/IconLoader.h"
+#include "src/common/loader/IIconLoader.h"
+#include "src/common/helper/PathHelper.h"
 
-class TrayIcon : public QSystemTrayIcon, public IToastService
+class TrayIcon : public QSystemTrayIcon, public INotificationService
 {
 Q_OBJECT
 public:
-	explicit TrayIcon(QObject *parent);
+	explicit TrayIcon(const QSharedPointer<IConfig> &config, const QSharedPointer<IIconLoader> &iconLoader, QObject *parent);
 	~TrayIcon() override;
 	void setCaptureActions(const QList<QAction*> &captureActions);
 	void setOpenAction(QAction *action);
@@ -45,15 +46,15 @@ public:
 	void setQuitAction(QAction *action);
 	void setActionsMenu(QMenu *actionsMenu);
 	void setEnabled(bool enabled);
-	void showInfoToast(const QString &title, const QString &message, const QString &contentUrl) override;
-	void showWarningToast(const QString &title, const QString &message, const QString &contentUrl) override;
-	void showCriticalToast(const QString &title, const QString &message, const QString &contentUrl) override;
+	void showInfo(const QString &title, const QString &message, const QString &contentUrl) override;
+	void showWarning(const QString &title, const QString &message, const QString &contentUrl) override;
+	void showCritical(const QString &title, const QString &message, const QString &contentUrl) override;
 
 signals:
 	void showEditorTriggered() const;
 
 private:
-	KsnipConfig *mConfig;
+	QSharedPointer<IConfig> mConfig;
 	QMenu mMenu;
 	QList<QAction*> mCaptureActions;
 	QAction *mOpenAction;
