@@ -18,21 +18,28 @@
  */
 
 #include "NotificationServiceFactory.h"
-#include "src/backend/config/KsnipConfigProvider.h"
 
 #if defined(UNIX_X11)
 #include "FreeDesktopNotificationService.h"
+#include "KdeDesktopNotificationService.h"
 #endif
 
-IToastService *NotificationServiceFactory::create(IToastService *defaultNotificationService)
+QSharedPointer<INotificationService> NotificationServiceFactory::create(
+	INotificationService *defaultNotificationService,
+	const QSharedPointer<IPlatformChecker> &platformChecker,
+	const QSharedPointer<IConfig> &config)
 {
 #if defined(UNIX_X11)
-	if (KsnipConfigProvider::instance()->platformSpecificNotificationServiceEnabled()) {
-		return new FreeDesktopNotificationService();
+	if (config->platformSpecificNotificationServiceEnabled()) {
+		if(platformChecker->isKde()) {
+			return QSharedPointer<INotificationService>(new KdeDesktopNotificationService());
+		} else {
+			return QSharedPointer<INotificationService>(new FreeDesktopNotificationService());
+		}
 	} else {
-		return defaultNotificationService;
+		return QSharedPointer<INotificationService>(defaultNotificationService);
 	}
 #else
-	return defaultNotificationService;
+	return QSharedPointer<INotificationService>(defaultNotificationService);
 #endif
 }
