@@ -24,18 +24,18 @@
 #include <QCheckBox>
 #include <QLabel>
 #include <QGridLayout>
-#include <QSpinBox>
+#include <QDoubleSpinBox>
 
-#include "src/backend/config/KsnipConfig.h"
+#include "src/backend/config/IConfig.h"
 #include "src/widgets/ColorButton.h"
 #include "src/widgets/NumericComboBox.h"
-#include "src/common/provider/ScaledSizeProvider.h"
+#include "src/common/provider/scaledSizeProvider/IScaledSizeProvider.h"
 
 class SnippingAreaSettings : public QGroupBox
 {
 Q_OBJECT
 public:
-	explicit SnippingAreaSettings(KsnipConfig *config);
+	explicit SnippingAreaSettings(const QSharedPointer<IConfig> &config, const QSharedPointer<IScaledSizeProvider> &scaledSizeProvider);
 	~SnippingAreaSettings() override;
 	void saveSettings();
 
@@ -46,22 +46,29 @@ private:
 	QCheckBox *mSnippingAreaMagnifyingGlassCheckbox;
 	QCheckBox *mAllowResizingRectSelectionCheckbox;
 	QCheckBox *mShowSnippingAreaInfoTextCheckbox;
+	QCheckBox *mSnippingAreaOffsetEnabledCheckbox;
 	QLabel *mSnippingCursorSizeLabel;
 	QLabel *mSnippingCursorColorLabel;
 	QLabel *mSnippingAdornerColorLabel;
 	QLabel *mSnippingAreaTransparencyLabel;
+	QLabel *mSnippingAreaOffsetXLabel;
+	QLabel *mSnippingAreaOffsetYLabel;
 	ColorButton *mSnippingCursorColorButton;
 	ColorButton *mSnippingAdornerColorButton;
 	NumericComboBox *mSnippingCursorSizeCombobox;
 	QSpinBox *mSnippingAreaTransparencySpinBox;
+	QDoubleSpinBox *mSnippingAreaOffsetXSpinBox;
+	QDoubleSpinBox *mSnippingAreaOffsetYSpinBox;
 	QGridLayout *mLayout;
-	KsnipConfig *mConfig;
+	QSharedPointer<IConfig> mConfig;
+	QSharedPointer<IScaledSizeProvider> mScaledSizeProvider;
+
 	void initGui();
 	void loadConfig();
 
 private slots:
 	void freezeImageWhileSnippingStateChanged();
+	void snippingAreaOffsetEnableStateChanged();
 };
 
-
 #endif //KSNIP_SNIPPINGAREASETTINGS_H
