@@ -19,14 +19,14 @@
 
 #include "MacSnippingArea.h"
 
-MacSnippingArea::MacSnippingArea() : AbstractSnippingArea()
+MacSnippingArea::MacSnippingArea(const QSharedPointer<IConfig> &config) : AbstractSnippingArea(config)
 {
     setWindowFlags(windowFlags() | Qt::WindowFullscreenButtonHint);
 }
 
 QRect MacSnippingArea::selectedRectArea() const
 {
-    return mHdpiScaler.scale(mCaptureArea);
+    return mHdpiScaler.scale(getCaptureArea());
 }
 
 void MacSnippingArea::setFullScreen()
@@ -35,7 +35,7 @@ void MacSnippingArea::setFullScreen()
     QWidget::showFullScreen();
 }
 
-QRect MacSnippingArea::getSnippingAreaGeometry() const
+QSizeF MacSnippingArea::getSize() const
 {
-    return geometry();
+    return QSizeF(geometry().size());
 }
\ No newline at end of file
