@@ -19,8 +19,8 @@
 
 #include "WinSnippingArea.h"
 
-WinSnippingArea::WinSnippingArea() :
-    AbstractSnippingArea(),
+WinSnippingArea::WinSnippingArea(const QSharedPointer<IConfig> &config) :
+    AbstractSnippingArea(config),
     mIsFullScreenSizeSet(false),
     mIsMultipleScaledScreens(false)
 {
@@ -34,16 +34,14 @@ WinSnippingArea::WinSnippingArea() :
 
 QRect WinSnippingArea::selectedRectArea() const
 {
+    auto captureArea = getCaptureArea();
+
     if(isBackgroundTransparent()) {
-        auto topLeft = mapToGlobal(mCaptureArea.topLeft());
-        auto bottomRight = mapToGlobal(mCaptureArea.bottomRight());
+        auto topLeft = mapToGlobal(captureArea.topLeft());
+        auto bottomRight = mapToGlobal(captureArea.bottomRight());
         return {topLeft, bottomRight};
-    } else if (mIsMultipleScaledScreens) {
-        auto xWithOffset = mCaptureArea.x() - mScaleOffset.x();
-        auto yWithOffset = mCaptureArea.y() - mScaleOffset.y();
-        return mHdpiScaler.scale({xWithOffset, yWithOffset, mCaptureArea.width(), mCaptureArea.height()});
     } else {
-        return mHdpiScaler.scale(mCaptureArea);
+        return mHdpiScaler.scale(captureArea);
     }
 }
 
@@ -71,25 +69,25 @@ void WinSnippingArea::setFullScreen()
     QWidget::show();
 }
 
-QRect WinSnippingArea::getSnippingAreaGeometry() const
+QSizeF WinSnippingArea::getSize() const
 {
-    if(mIsMultipleScaledScreens) {
-        return {mScaleOffset.x(), mScaleOffset.y(), mFullScreenRect.width() / 2, mFullScreenRect.height() / 2 };
+    if (mIsMultipleScaledScreens) {
+        return { static_cast<double>(mFullScreenRect.width()) / 2, static_cast<double>(mFullScreenRect.height()) / 2 };
     } else {
-        return {0, 0, geometry().width(), geometry().height() };
+        return { static_cast<double>(geometry().width()), static_cast<double>(geometry().height()) };
     }
 }
 
-QPoint WinSnippingArea::getLocalCursorPosition() const
+QPoint WinSnippingArea::getGlobalCursorPosition() const
 {
-    return mapFromGlobal(QCursor::pos());
+    return mapFromGlobal(AbstractSnippingArea::getGlobalCursorPosition());
 }
 
 void WinSnippingArea::setupScalingVariables()
 {
     auto scaledScreens = 0;
     auto screens = QApplication::screens();
-    for(auto screen : screens) {
+    for (auto screen : screens) {
         auto screenGeometry = screen->geometry();
         
         if(screen->devicePixelRatio() > 1) {
@@ -97,16 +95,16 @@ void WinSnippingArea::setupScalingVariables()
         }
 
         if (screenGeometry.x() != 0) {
-            mScaleOffset.setX(screenGeometry.x());
+            mScalePosition.setX(screenGeometry.x());
         }
 
         if (screenGeometry.y() != 0) {
-            mScaleOffset.setY(screenGeometry.y());
+            mScalePosition.setY(screenGeometry.y());
         }
     }
 
-    mScaleOffset.setX((mScaleOffset.x() - mFullScreenRect.x()) / mHdpiScaler.scaleFactor());
-    mScaleOffset.setY((mScaleOffset.y() - mFullScreenRect.y()) / mHdpiScaler.scaleFactor());
+    mScalePosition.setX((mScalePosition.x() - mFullScreenRect.x()) / mHdpiScaler.scaleFactor());
+    mScalePosition.setY((mScalePosition.y() - mFullScreenRect.y()) / mHdpiScaler.scaleFactor());
 
     mIsMultipleScaledScreens = scaledScreens > 1;
 }
@@ -118,3 +116,12 @@ void WinSnippingArea::init()
     mFullScreenRect = mWinWrapper.getFullScreenRect();
     setupScalingVariables();
 }
+
+QPointF WinSnippingArea::getPosition() const
+{
+    if (mIsMultipleScaledScreens) {
+        return mScalePosition;
+    } else {
+        return AbstractSnippingArea::getPosition();
+    }
+}
