@@ -102,6 +102,15 @@
         <source>Hide Main Window</source>
         <translation>Hauptfenster verstecken</translation>
     </message>
+    <message>
+        <source>Global</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When enabled will make the shortcut
+available even when ksnip has no focus.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ActionsSettings</name>
@@ -197,6 +206,15 @@ being created, allowing changing settings.</source>
         <translation>Mit dieser Option wird das Objekt nach dem Erstellen
 ausgewählt, was eine Änderung der Einstellungen erlaubt.</translation>
     </message>
+    <message>
+        <source>Show Controls Widget</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The Controls Widget contains the Undo/Redo,
+Crop, Scale, Rotate and Modify Canvas buttons.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ApplicationSettings</name>
@@ -284,10 +302,6 @@ Change requires ksnip restart to take effect.</source>
         <translation>Aktiviert das Schreiben von Debug-Ausgaben in die Konsole.
 Eine Änderung erfordert den Neustart von ksnip.</translation>
     </message>
-    <message>
-        <source>Resize to content delay</source>
-        <translation>Verzögerung bis zum Skalieren</translation>
-    </message>
     <message>
         <source>Resizing to content is delay to allow the Window Manager to receive
 the new content. In case that the Main Windows is not adjusted correctly
@@ -296,6 +310,23 @@ to the new content, increasing this delay might improve the behavior.</source>
 des neuen Inhaltes zu erlauben. Falls die Hauptfenster für den neuen Inhalt nicht korrekt
 ausgerichtet sind, kann eine Erhöhung dieser Verzögerung jenes Verhalten verbessern.</translation>
     </message>
+    <message>
+        <source>Resize delay</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Temp Directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Temp directory used for storing temporary images that are
+going to be deleted after ksnip closes.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Browse</source>
+        <translation type="unfinished">Durchsuchen</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -705,6 +736,19 @@ wenn jenes versteckt oder minimiert war.</translation>
         <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
         <translation>Generische Wayland-Screenshots (xdg-desktop-portal) skalieren</translation>
     </message>
+    <message>
+        <source>Implicit capture delay</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This delay is used when no delay was selected in
+the UI, it allows ksnip to hide before taking
+a screenshot. This value is not applied when
+ksnip was already minimized. Reducing this value
+can have the effect that ksnip&apos;s main window is
+visible on the screenshot.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -824,6 +868,14 @@ Changing requires restart.</source>
         <source>Clear Token</source>
         <translation>Token löschen</translation>
     </message>
+    <message>
+        <source>Upload title:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload description:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LoadImageFromFileOperation</name>
@@ -1060,6 +1112,22 @@ und der Aufnahme des Bildschirmfotos.</translation>
         <source>Image Files</source>
         <translation>Bilddateien</translation>
     </message>
+    <message>
+        <source>Save All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Close Window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OCR</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1091,6 +1159,10 @@ und der Aufnahme des Bildschirmfotos.</translation>
         <source>Rename</source>
         <translation>Umbenennen</translation>
     </message>
+    <message>
+        <source>Save All</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>NewCaptureNameProvider</name>
@@ -1099,6 +1171,13 @@ und der Aufnahme des Bildschirmfotos.</translation>
         <translation>Aufnahme</translation>
     </message>
 </context>
+<context>
+    <name>OcrWindowCreator</name>
+    <message>
+        <source>OCR Window %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>PinWindow</name>
     <message>
@@ -1115,10 +1194,56 @@ und der Aufnahme des Bildschirmfotos.</translation>
     </message>
 </context>
 <context>
-    <name>PinWindowHandler</name>
+    <name>PinWindowCreator</name>
     <message>
-        <source>Pin Window %1</source>
-        <translation>Hefte Fenster %1 an</translation>
+        <source>OCR Window %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>PluginsSettings</name>
+    <message>
+        <source>Search Path</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Default</source>
+        <translation type="unfinished">Standard</translation>
+    </message>
+    <message>
+        <source>The directory where the plugins are located.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Browse</source>
+        <translation type="unfinished">Durchsuchen</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished">Name</translation>
+    </message>
+    <message>
+        <source>Version</source>
+        <translation type="unfinished">Version</translation>
+    </message>
+    <message>
+        <source>Detect</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Plugin Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Plugin location</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ProcessIndicator</name>
+    <message>
+        <source>Processing</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1243,6 +1368,10 @@ Not all image formats support the full range, JPEG does.</source>
         <translation>0 angeben, um kleine komprimierte Dateien zu erhalten, 100 für große unkomprimierte Dateien.
 Nicht alle Bildformate unterstützen die gesamte Bandbreite, JPEG schon.</translation>
     </message>
+    <message>
+        <source>Overwrite file with same name</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ScriptUploaderSettings</name>
@@ -1363,6 +1492,14 @@ Falls leer, wird alles kopiert.</translation>
         <source>FTP Uploader</source>
         <translation>FTP-Uploader</translation>
     </message>
+    <message>
+        <source>Plugins</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Search Settings...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1382,14 +1519,18 @@ Falls leer, wird alles kopiert.</translation>
         <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
         <translation>Verwenden Sie die Pfeiltasten bei gedrückter ALT-Taste, um den unteren rechten Griff zu verschieben.</translation>
     </message>
-    <message>
-        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
-        <translation>Bestätigen Sie die Auswahl durch Drücken von ENTER/Eingabe-Taste oder brechen Sie mit ESC ab.</translation>
-    </message>
     <message>
         <source>This message can be disabled via settings.</source>
         <translation>Diese Nachricht kann in den Einstellungen deaktiviert werden.</translation>
     </message>
+    <message>
+        <source>Confirm selection by pressing ENTER/RETURN or mouse double-click anywhere.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Abort by pressing ESC.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaSelectorInfoText</name>
@@ -1532,6 +1673,26 @@ Smaller number is more transparent.</source>
         <translation>Alpha-Wert für nicht ausgewählte Regionen im Aufnahmebereich.
 Kleinere Werte bedeuten mehr Transparenz.</translation>
     </message>
+    <message>
+        <source>Enable Snipping Area offset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When enabled will apply the configured
+offset to the Snipping Area position which
+is required when the position is not
+correctly calculated. This is sometimes
+required with screen scaling enabled.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>X</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Y</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StickerSettings</name>
