@@ -102,6 +102,16 @@
         <source>Hide Main Window</source>
         <translation>Ezkutatu leiho nagusia</translation>
     </message>
+    <message>
+        <source>Global</source>
+        <translation>Orokorra</translation>
+    </message>
+    <message>
+        <source>When enabled will make the shortcut
+available even when ksnip has no focus.</source>
+        <translation>Gaituta dagoenean lasterbidea egingo du
+eskuragarri ksnip-ek fokurik ez duenean ere.</translation>
+    </message>
 </context>
 <context>
     <name>ActionsSettings</name>
@@ -197,6 +207,16 @@ being created, allowing changing settings.</source>
         <translation>Aukera hau gaituta dagoenean, elementua hautatuta geratzen 
 da sortu ondoren, hartara ezarpenak aldatu daitezke.</translation>
     </message>
+    <message>
+        <source>Show Controls Widget</source>
+        <translation>Erakutsi kontrolen widgeta</translation>
+    </message>
+    <message>
+        <source>The Controls Widget contains the Undo/Redo,
+Crop, Scale, Rotate and Modify Canvas buttons.</source>
+        <translation>Kontrolen widgetak du: Desegin/Berregin,
+Moztu, Eskalatu, Biratu eta Aldatu Canvas botoiak.</translation>
+    </message>
 </context>
 <context>
     <name>ApplicationSettings</name>
@@ -284,10 +304,6 @@ Change requires ksnip restart to take effect.</source>
         <translation>Arazte-irteera gaitzen du kontsolan idatzita.
 Ksnip berrabiarazi behar da eragina izateko.</translation>
     </message>
-    <message>
-        <source>Resize to content delay</source>
-        <translation>Edukira doitzeko atzerapena</translation>
-    </message>
     <message>
         <source>Resizing to content is delay to allow the Window Manager to receive
 the new content. In case that the Main Windows is not adjusted correctly
@@ -296,6 +312,24 @@ to the new content, increasing this delay might improve the behavior.</source>
 atzerapena da. Leiho nagusia eduki berrira behar bezala doitzen ez bada,
 atzerapen hori handitzeak portaera hobe dezake.</translation>
     </message>
+    <message>
+        <source>Resize delay</source>
+        <translation>Aldatu atzerapena</translation>
+    </message>
+    <message>
+        <source>Temp Directory</source>
+        <translation>Temp direktorioa</translation>
+    </message>
+    <message>
+        <source>Temp directory used for storing temporary images that are
+going to be deleted after ksnip closes.</source>
+        <translation>Temp direktorioa aldi baterako irudiak gordetzeko erabiltzen da,
+ksnip itxi ondoren ezabatu egingo da.</translation>
+    </message>
+    <message>
+        <source>Browse</source>
+        <translation>Arakatu</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -705,6 +739,24 @@ leiho nagusia ezkutuan edo minimizatuta dagoenean.</translation>
         <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
         <translation>Eskalatu Generic Wayland (xdg-desktop-portal) pantaila-argazkia</translation>
     </message>
+    <message>
+        <source>Implicit capture delay</source>
+        <translation>Kapturaren atzerapen inplizitua</translation>
+    </message>
+    <message>
+        <source>This delay is used when no delay was selected in
+the UI, it allows ksnip to hide before taking
+a screenshot. This value is not applied when
+ksnip was already minimized. Reducing this value
+can have the effect that ksnip&apos;s main window is
+visible on the screenshot.</source>
+        <translation>Atzerapen hau atzerapenik hautatu ez denean erabiltzen 
+da, Ksnip pantaila-argazki bat egin aurretik ezkutatzeko 
+aukera ematen du. Balio hau ez da aplikatzen Ksnip 
+dagoeneko minimizatuta badago. Balio hori murrizteak 
+eragin dezake Ksnip-en leiho nagusia pantaila-argazkian 
+agertzea.</translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -824,6 +876,14 @@ Aldatzeak berrabiaraztea eskatzen du.</translation>
         <source>Clear Token</source>
         <translation>Garbitu Tokena</translation>
     </message>
+    <message>
+        <source>Upload title:</source>
+        <translation>Kargatu izenburua:</translation>
+    </message>
+    <message>
+        <source>Upload description:</source>
+        <translation>Kargatu deskribapena:</translation>
+    </message>
 </context>
 <context>
     <name>LoadImageFromFileOperation</name>
@@ -1060,6 +1120,22 @@ eta pantaila-argazkiaren artean.</translation>
         <source>Image Files</source>
         <translation>Irudi fitxategiak</translation>
     </message>
+    <message>
+        <source>Save All</source>
+        <translation>Gorde guztiak</translation>
+    </message>
+    <message>
+        <source>Close Window</source>
+        <translation>Itxi leihoa</translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation>Moztu</translation>
+    </message>
+    <message>
+        <source>OCR</source>
+        <translation>OCR</translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1091,6 +1167,10 @@ eta pantaila-argazkiaren artean.</translation>
         <source>Rename</source>
         <translation>Aldatu izena</translation>
     </message>
+    <message>
+        <source>Save All</source>
+        <translation>Gorde guztiak</translation>
+    </message>
 </context>
 <context>
     <name>NewCaptureNameProvider</name>
@@ -1099,6 +1179,13 @@ eta pantaila-argazkiaren artean.</translation>
         <translation>Argazkia</translation>
     </message>
 </context>
+<context>
+    <name>OcrWindowCreator</name>
+    <message>
+        <source>OCR Window %1</source>
+        <translation>OCR leihoa %1</translation>
+    </message>
+</context>
 <context>
     <name>PinWindow</name>
     <message>
@@ -1115,10 +1202,56 @@ eta pantaila-argazkiaren artean.</translation>
     </message>
 </context>
 <context>
-    <name>PinWindowHandler</name>
+    <name>PinWindowCreator</name>
     <message>
-        <source>Pin Window %1</source>
-        <translation>Ainguratu %1 leihoa</translation>
+        <source>OCR Window %1</source>
+        <translation>OCR leihoa %1</translation>
+    </message>
+</context>
+<context>
+    <name>PluginsSettings</name>
+    <message>
+        <source>Search Path</source>
+        <translation>Bilaketa-bidea</translation>
+    </message>
+    <message>
+        <source>Default</source>
+        <translation>Lehenetsia</translation>
+    </message>
+    <message>
+        <source>The directory where the plugins are located.</source>
+        <translation>Pluginak dauden direktorioa.</translation>
+    </message>
+    <message>
+        <source>Browse</source>
+        <translation>Arakatu</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Izena</translation>
+    </message>
+    <message>
+        <source>Version</source>
+        <translation>Bertsioa</translation>
+    </message>
+    <message>
+        <source>Detect</source>
+        <translation>Antzeman</translation>
+    </message>
+    <message>
+        <source>Plugin Settings</source>
+        <translation>Plugin ezarpenak</translation>
+    </message>
+    <message>
+        <source>Plugin location</source>
+        <translation>Plugin kokapena</translation>
+    </message>
+</context>
+<context>
+    <name>ProcessIndicator</name>
+    <message>
+        <source>Processing</source>
+        <translation>Prozesatzen</translation>
     </message>
 </context>
 <context>
@@ -1243,6 +1376,10 @@ Not all image formats support the full range, JPEG does.</source>
         <translation>Jarri 0 konprimitutako fitxategi txikiak sortzeko, 100 konpresiorik gabeko fitxategiak sortzeko.
 Irudi formatu guztiek ez dute gama osoa onartzen, JPEG-ek bai.</translation>
     </message>
+    <message>
+        <source>Overwrite file with same name</source>
+        <translation>Gainidatzi fitxategia izen berdinarekin</translation>
+    </message>
 </context>
 <context>
     <name>ScriptUploaderSettings</name>
@@ -1363,6 +1500,14 @@ Ez badago, dena kopiatzen da.</translation>
         <source>FTP Uploader</source>
         <translation>FTP kargatzailea</translation>
     </message>
+    <message>
+        <source>Plugins</source>
+        <translation>Pluginak</translation>
+    </message>
+    <message>
+        <source>Search Settings...</source>
+        <translation>Bilaketa ezarpenak...</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1382,14 +1527,18 @@ Ez badago, dena kopiatzen da.</translation>
         <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
         <translation>Erabili gezi-teklak ALT sakatzen duzun bitartean beheko eskuineko heldulekua mugitzeko.</translation>
     </message>
-    <message>
-        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
-        <translation>Berretsi hautamena SARTU sakatuta edo utzi ESC sakatuta.</translation>
-    </message>
     <message>
         <source>This message can be disabled via settings.</source>
         <translation>Mezu hau ezarpenen bidez desgaitu daiteke.</translation>
     </message>
+    <message>
+        <source>Confirm selection by pressing ENTER/RETURN or mouse double-click anywhere.</source>
+        <translation>Berretsi hautapena SARTU sakatuz edo saguaren klik bikoitza egin edozein lekutan.</translation>
+    </message>
+    <message>
+        <source>Abort by pressing ESC.</source>
+        <translation>Utzi ESC sakatuz.</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaSelectorInfoText</name>
@@ -1532,6 +1681,31 @@ Smaller number is more transparent.</source>
         <translation>Argazki-areako hautatu gabeko zonaren Alpha.
 Zenbaki txikiagoak gardenagoa adierazten du.</translation>
     </message>
+    <message>
+        <source>Enable Snipping Area offset</source>
+        <translation>Gaitu ebakitzeko eremuaren desplazamendua</translation>
+    </message>
+    <message>
+        <source>When enabled will apply the configured
+offset to the Snipping Area position which
+is required when the position is not
+correctly calculated. This is sometimes
+required with screen scaling enabled.</source>
+        <translation>Gaituta dagoenean konfiguratutako 
+desplazamendua aplikatuko zaio mozteko 
+areari posiziora kokapena behar bezala 
+kalkulatuta ez denean. Hau batzuetan 
+beharrezkoa da pantaila eskalatzea 
+gaituta dagoenean.</translation>
+    </message>
+    <message>
+        <source>X</source>
+        <translation>X</translation>
+    </message>
+    <message>
+        <source>Y</source>
+        <translation>Y</translation>
+    </message>
 </context>
 <context>
     <name>StickerSettings</name>
