@@ -102,6 +102,15 @@
         <source>Hide Main Window</source>
         <translation>Piilota pääikkuna</translation>
     </message>
+    <message>
+        <source>Global</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When enabled will make the shortcut
+available even when ksnip has no focus.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ActionsSettings</name>
@@ -197,6 +206,15 @@ being created, allowing changing settings.</source>
         <translation>Kun käytössä, kohde valitaan luomisen jälkeen,
 jolloin asetuksia voidaan muuttaa.</translation>
     </message>
+    <message>
+        <source>Show Controls Widget</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The Controls Widget contains the Undo/Redo,
+Crop, Scale, Rotate and Modify Canvas buttons.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ApplicationSettings</name>
@@ -284,10 +302,6 @@ Change requires ksnip restart to take effect.</source>
         <translation>Ottaa käyttöön konsoliin kirjoitettavan debug-listauksen.
 Muutos vaatii ksnipin käynnistyksen tullakseen voimaan.</translation>
     </message>
-    <message>
-        <source>Resize to content delay</source>
-        <translation>Muuta kokoa sisällön viiveen mukaan</translation>
-    </message>
     <message>
         <source>Resizing to content is delay to allow the Window Manager to receive
 the new content. In case that the Main Windows is not adjusted correctly
@@ -296,6 +310,23 @@ to the new content, increasing this delay might improve the behavior.</source>
 uutta sisältöä. Jos pääikkunaa ei ole säädetty oikein uuteen sisältöön,
 viiveen lisääminen saattaa parantaa toimintaa.</translation>
     </message>
+    <message>
+        <source>Resize delay</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Temp Directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Temp directory used for storing temporary images that are
+going to be deleted after ksnip closes.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Browse</source>
+        <translation type="unfinished">Selaa</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -705,6 +736,19 @@ pääikkuna oli piilotettu tai minimoitu.</translation>
         <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
         <translation>Skaalaa Wayland (xdg-desktop-portal) ruudunkaappaus</translation>
     </message>
+    <message>
+        <source>Implicit capture delay</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This delay is used when no delay was selected in
+the UI, it allows ksnip to hide before taking
+a screenshot. This value is not applied when
+ksnip was already minimized. Reducing this value
+can have the effect that ksnip&apos;s main window is
+visible on the screenshot.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -824,6 +868,14 @@ Muuttaminen vaatii ohjelman käynnistyksen uudelleen.</translation>
         <source>Clear Token</source>
         <translation>Tyhjennä tunnus</translation>
     </message>
+    <message>
+        <source>Upload title:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload description:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LoadImageFromFileOperation</name>
@@ -1060,6 +1112,22 @@ ottamisen välillä.</translation>
         <source>Image Files</source>
         <translation>Kuvatiedostot</translation>
     </message>
+    <message>
+        <source>Save All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Close Window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OCR</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1091,6 +1159,10 @@ ottamisen välillä.</translation>
         <source>Rename</source>
         <translation>Nimeä uudelleen</translation>
     </message>
+    <message>
+        <source>Save All</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>NewCaptureNameProvider</name>
@@ -1099,6 +1171,13 @@ ottamisen välillä.</translation>
         <translation>Kaappaa</translation>
     </message>
 </context>
+<context>
+    <name>OcrWindowCreator</name>
+    <message>
+        <source>OCR Window %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>PinWindow</name>
     <message>
@@ -1115,10 +1194,56 @@ ottamisen välillä.</translation>
     </message>
 </context>
 <context>
-    <name>PinWindowHandler</name>
+    <name>PinWindowCreator</name>
     <message>
-        <source>Pin Window %1</source>
-        <translation>Kiinnitä ikkuna %1</translation>
+        <source>OCR Window %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>PluginsSettings</name>
+    <message>
+        <source>Search Path</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Default</source>
+        <translation type="unfinished">Oletus</translation>
+    </message>
+    <message>
+        <source>The directory where the plugins are located.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Browse</source>
+        <translation type="unfinished">Selaa</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished">Nimi</translation>
+    </message>
+    <message>
+        <source>Version</source>
+        <translation type="unfinished">Versio</translation>
+    </message>
+    <message>
+        <source>Detect</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Plugin Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Plugin location</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ProcessIndicator</name>
+    <message>
+        <source>Processing</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1243,6 +1368,10 @@ Not all image formats support the full range, JPEG does.</source>
         <translation>Määritä 0, jos haluat hankkia pieniä pakattuja tiedostoja, 100 suurille pakkaamattomille
 tiedostoille. Kaikki kuvamuodot eivät tue täyttä aluetta, mutta JPEG tukee.</translation>
     </message>
+    <message>
+        <source>Overwrite file with same name</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ScriptUploaderSettings</name>
@@ -1363,6 +1492,14 @@ Kun kaikki jätetään pois, kaikki kopioidaan.</translation>
         <source>FTP Uploader</source>
         <translation>FTP-lataaja</translation>
     </message>
+    <message>
+        <source>Plugins</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Search Settings...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1382,14 +1519,18 @@ Kun kaikki jätetään pois, kaikki kopioidaan.</translation>
         <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
         <translation>Siirrä oikeaa alakahvaa nuolinäppäimillä ja paina samalla ALT-näppäintä.</translation>
     </message>
-    <message>
-        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
-        <translation>Vahvista valinta painamalla ENTER/RETURN tai keskeytä painamalla ESC.</translation>
-    </message>
     <message>
         <source>This message can be disabled via settings.</source>
         <translation>Tämä viesti voidaan poistaa käytöstä asetuksissa.</translation>
     </message>
+    <message>
+        <source>Confirm selection by pressing ENTER/RETURN or mouse double-click anywhere.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Abort by pressing ESC.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaSelectorInfoText</name>
@@ -1532,6 +1673,26 @@ Smaller number is more transparent.</source>
         <translation>Alpha-arvo ei valittulla leikkausalueella.
 Pienempi numero on läpinäkyvämpi.</translation>
     </message>
+    <message>
+        <source>Enable Snipping Area offset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When enabled will apply the configured
+offset to the Snipping Area position which
+is required when the position is not
+correctly calculated. This is sometimes
+required with screen scaling enabled.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>X</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Y</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StickerSettings</name>
