@@ -102,6 +102,16 @@
         <source>Hide Main Window</source>
         <translation>Nascondi finestra principale</translation>
     </message>
+    <message>
+        <source>Global</source>
+        <translation>Globale</translation>
+    </message>
+    <message>
+        <source>When enabled will make the shortcut
+available even when ksnip has no focus.</source>
+        <translation>Quando abilitato, creerà il collegamento
+disponibile anche quando ksnip non ha focus.</translation>
+    </message>
 </context>
 <context>
     <name>ActionsSettings</name>
@@ -197,6 +207,16 @@ being created, allowing changing settings.</source>
         <translation>Con questa opzione abilitata l&apos;elemento viene selezionato dopo
 essere stato creato, consentendo la modifica delle impostazioni.</translation>
     </message>
+    <message>
+        <source>Show Controls Widget</source>
+        <translation>Mostra controlli Widget</translation>
+    </message>
+    <message>
+        <source>The Controls Widget contains the Undo/Redo,
+Crop, Scale, Rotate and Modify Canvas buttons.</source>
+        <translation>Il widget dei controlli contiene i pulsanti Annulla/Ripeti,
+Ritaglia, Ridimensiona, Ruota e Modifica tela.</translation>
+    </message>
 </context>
 <context>
     <name>ApplicationSettings</name>
@@ -284,10 +304,6 @@ Change requires ksnip restart to take effect.</source>
         <translation>Abilita l&apos;output di debug scritto nella console.
 La modifica richiede il riavvio di ksnip per avere effetto.</translation>
     </message>
-    <message>
-        <source>Resize to content delay</source>
-        <translation>Ridimensiona al ritardo del contenuto</translation>
-    </message>
     <message>
         <source>Resizing to content is delay to allow the Window Manager to receive
 the new content. In case that the Main Windows is not adjusted correctly
@@ -296,6 +312,24 @@ to the new content, increasing this delay might improve the behavior.</source>
 il nuovo contenuto. Nel caso in cui la finestra principale non sia regolata correttamente
 al nuovo contenuto, aumentare questo ritardo potrebbe migliorare il comportamento.</translation>
     </message>
+    <message>
+        <source>Resize delay</source>
+        <translation>Ridimensiona ritardo</translation>
+    </message>
+    <message>
+        <source>Temp Directory</source>
+        <translation>Directory temporanea</translation>
+    </message>
+    <message>
+        <source>Temp directory used for storing temporary images that are
+going to be deleted after ksnip closes.</source>
+        <translation>Directory temporanea utilizzata per memorizzare immagini temporanee che 
+verranno eliminato dopo la chiusura di ksnip.</translation>
+    </message>
+    <message>
+        <source>Browse</source>
+        <translation>Sfoglia</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -705,6 +739,24 @@ quando la finestra principale era nascosta o ridotta a icona.</translation>
         <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
         <translation>Schermate di Scale Generic Wayland (xdg-desktop-portal)</translation>
     </message>
+    <message>
+        <source>Implicit capture delay</source>
+        <translation>Ritardo di cattura implicito</translation>
+    </message>
+    <message>
+        <source>This delay is used when no delay was selected in
+the UI, it allows ksnip to hide before taking
+a screenshot. This value is not applied when
+ksnip was already minimized. Reducing this value
+can have the effect that ksnip&apos;s main window is
+visible on the screenshot.</source>
+        <translation>Questo ritardo viene utilizzato quando non è stato selezionato alcun ritardo
+nell&apos;UI, questo permette a ksnip di nascondersi prima di prendere
+uno screenshot. Questo valore non viene applicato quando
+ksnip era già minimizzato. Ridurre questo valore
+può avere l&apos;effetto che la finestra principale di ksnip sia
+visibile sullo screenshot.</translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -824,6 +876,14 @@ La modifica richiede il riavvio.</translation>
         <source>Clear Token</source>
         <translation>Cancella token</translation>
     </message>
+    <message>
+        <source>Upload title:</source>
+        <translation>Carica titolo:</translation>
+    </message>
+    <message>
+        <source>Upload description:</source>
+        <translation>Carica descrizione:</translation>
+    </message>
 </context>
 <context>
     <name>LoadImageFromFileOperation</name>
@@ -1060,6 +1120,22 @@ e cattura screenshot.</translation>
         <source>Image Files</source>
         <translation>File immagine</translation>
     </message>
+    <message>
+        <source>Save All</source>
+        <translation>Salva tutto</translation>
+    </message>
+    <message>
+        <source>Close Window</source>
+        <translation>Chiudi finestra</translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation>Taglia</translation>
+    </message>
+    <message>
+        <source>OCR</source>
+        <translation>OCR</translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1091,6 +1167,10 @@ e cattura screenshot.</translation>
         <source>Rename</source>
         <translation>Rinomina</translation>
     </message>
+    <message>
+        <source>Save All</source>
+        <translation>Salva tutto</translation>
+    </message>
 </context>
 <context>
     <name>NewCaptureNameProvider</name>
@@ -1099,6 +1179,13 @@ e cattura screenshot.</translation>
         <translation>Cattura</translation>
     </message>
 </context>
+<context>
+    <name>OcrWindowCreator</name>
+    <message>
+        <source>OCR Window %1</source>
+        <translation>Finestra OCR %1</translation>
+    </message>
+</context>
 <context>
     <name>PinWindow</name>
     <message>
@@ -1115,10 +1202,56 @@ e cattura screenshot.</translation>
     </message>
 </context>
 <context>
-    <name>PinWindowHandler</name>
+    <name>PinWindowCreator</name>
     <message>
-        <source>Pin Window %1</source>
-        <translation>Blocca Finestra %1</translation>
+        <source>OCR Window %1</source>
+        <translation>Finestra OCR %1</translation>
+    </message>
+</context>
+<context>
+    <name>PluginsSettings</name>
+    <message>
+        <source>Search Path</source>
+        <translation>Percorso di ricerca</translation>
+    </message>
+    <message>
+        <source>Default</source>
+        <translation>Predefinito</translation>
+    </message>
+    <message>
+        <source>The directory where the plugins are located.</source>
+        <translation>La directory in cui si trovano i plugin.</translation>
+    </message>
+    <message>
+        <source>Browse</source>
+        <translation>Sfoglia</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Nome</translation>
+    </message>
+    <message>
+        <source>Version</source>
+        <translation>Versione</translation>
+    </message>
+    <message>
+        <source>Detect</source>
+        <translation>Rileva</translation>
+    </message>
+    <message>
+        <source>Plugin Settings</source>
+        <translation>Impostazioni dei plugin</translation>
+    </message>
+    <message>
+        <source>Plugin location</source>
+        <translation>Posizione del plugin</translation>
+    </message>
+</context>
+<context>
+    <name>ProcessIndicator</name>
+    <message>
+        <source>Processing</source>
+        <translation>Elaborazione in corso</translation>
     </message>
 </context>
 <context>
@@ -1243,6 +1376,10 @@ Not all image formats support the full range, JPEG does.</source>
         <translation>Specificare 0 per ottenere file compressi di piccole dimensioni, 100 per file non compressi di grandi dimensioni.
 Non tutti i formati di immagine supportano l&apos;intera gamma, JPEG lo fa.</translation>
     </message>
+    <message>
+        <source>Overwrite file with same name</source>
+        <translation>Sovrascrivi il file con lo stesso nome</translation>
+    </message>
 </context>
 <context>
     <name>ScriptUploaderSettings</name>
@@ -1363,6 +1500,14 @@ copiato negli appunti. Se non è definito alcun filtro, verranno copiate tutte l
         <source>FTP Uploader</source>
         <translation>Uploader FTP</translation>
     </message>
+    <message>
+        <source>Plugins</source>
+        <translation>Plugin</translation>
+    </message>
+    <message>
+        <source>Search Settings...</source>
+        <translation>Impostazioni di ricerca...</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1382,14 +1527,18 @@ copiato negli appunti. Se non è definito alcun filtro, verranno copiate tutte l
         <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
         <translation>Utilizzare i tasti freccia mentre si preme ALT per spostare la maniglia in basso a destra.</translation>
     </message>
-    <message>
-        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
-        <translation>Confermare la selezione premendo ENTER/RETURN o interrompere premendo ESC.</translation>
-    </message>
     <message>
         <source>This message can be disabled via settings.</source>
         <translation>Questo messaggio può essere disabilitato tramite le impostazioni.</translation>
     </message>
+    <message>
+        <source>Confirm selection by pressing ENTER/RETURN or mouse double-click anywhere.</source>
+        <translation>Confermare la selezione premendo ENTER/RETURN o facendo doppio clic con il mouse su un punto qualsiasi.</translation>
+    </message>
+    <message>
+        <source>Abort by pressing ESC.</source>
+        <translation>Interrompere premendo ESC.</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaSelectorInfoText</name>
@@ -1532,6 +1681,30 @@ Smaller number is more transparent.</source>
         <translation>Alfa per la regione non selezionata nell&apos;area di cattura.
 Il numero più piccolo è più trasparente.</translation>
     </message>
+    <message>
+        <source>Enable Snipping Area offset</source>
+        <translation>Abilita l&apos;offset dell&apos;area di ritaglio</translation>
+    </message>
+    <message>
+        <source>When enabled will apply the configured
+offset to the Snipping Area position which
+is required when the position is not
+correctly calculated. This is sometimes
+required with screen scaling enabled.</source>
+        <translation>Se abilitato, applica l&apos;offset configurato alla posizione dell&apos;area di
+alla posizione dell&apos;area di ritaglio, che
+è necessario quando la posizione non è
+calcolata correttamente. Questo è talvolta
+necessario con il ridimensionamento dello schermo abilitato.</translation>
+    </message>
+    <message>
+        <source>X</source>
+        <translation>X</translation>
+    </message>
+    <message>
+        <source>Y</source>
+        <translation>Y</translation>
+    </message>
 </context>
 <context>
     <name>StickerSettings</name>
