@@ -102,6 +102,16 @@
         <source>Hide Main Window</source>
         <translation>Ukryj główne okno</translation>
     </message>
+    <message>
+        <source>Global</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When enabled will make the shortcut
+available even when ksnip has no focus.</source>
+        <translation type="unfinished">Włączenie tej opcji spowoduje, że skrót będzie
+dostępny nawet wtedy, gdy ksnip nie jest skupiony.</translation>
+    </message>
 </context>
 <context>
     <name>ActionsSettings</name>
@@ -197,6 +207,16 @@ being created, allowing changing settings.</source>
         <translation>Po włączeniu tej opcji element jest zaznaczany po
 utworzeniu, co pozwala na zmianę ustawień.</translation>
     </message>
+    <message>
+        <source>Show Controls Widget</source>
+        <translation>Pokaż widżet Sterowanie</translation>
+    </message>
+    <message>
+        <source>The Controls Widget contains the Undo/Redo,
+Crop, Scale, Rotate and Modify Canvas buttons.</source>
+        <translation>Widżet Sterowanie zawiera opcje Cofnij/Ponów,
+Przyciski Kadruj, Skaluj, Obróć i Modyfikuj obszar roboczy.</translation>
+    </message>
 </context>
 <context>
     <name>ApplicationSettings</name>
@@ -284,10 +304,6 @@ Change requires ksnip restart to take effect.</source>
         <translation>Włącza debugowanie danych wyjściowych zapisanych w konsoli.
 Zmiana wymaga ponownego uruchomienia ksnip.</translation>
     </message>
-    <message>
-        <source>Resize to content delay</source>
-        <translation>Zmiana rozmiaru do opóźnienia zawartości</translation>
-    </message>
     <message>
         <source>Resizing to content is delay to allow the Window Manager to receive
 the new content. In case that the Main Windows is not adjusted correctly
@@ -296,6 +312,24 @@ to the new content, increasing this delay might improve the behavior.</source>
 nowej zawartości. W przypadku, gdy główne okno nie jest poprawnie dostosowane
 do nowej zawartości, zwiększenie tego opóźnienia może poprawić zachowanie.</translation>
     </message>
+    <message>
+        <source>Resize delay</source>
+        <translation type="unfinished">Zmiana rozmiaru opóźnienia</translation>
+    </message>
+    <message>
+        <source>Temp Directory</source>
+        <translation>Katalog Temp</translation>
+    </message>
+    <message>
+        <source>Temp directory used for storing temporary images that are
+going to be deleted after ksnip closes.</source>
+        <translation>Katalog Temp służy do przechowywania tymczasowych obrazów, które
+zostaną usunięte po zamknięciu ksnipa.</translation>
+    </message>
+    <message>
+        <source>Browse</source>
+        <translation>Przeglądaj</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -699,12 +733,30 @@ kiedy główne okno było ukryte lub zminimalizowane.</translation>
     </message>
     <message>
         <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
-        <translation type="unfinished">Zrzut ekranu Force Generic Wayland (xdg-desktop-portal)</translation>
+        <translation>Wymuś zrzut ekranu poprzez generyczny podsystem Wayland (xdg-desktop-portal)</translation>
     </message>
     <message>
         <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
         <translation>Skaluj ogólne zrzuty ekranu Wayland (xdg-desktop-portal)</translation>
     </message>
+    <message>
+        <source>Implicit capture delay</source>
+        <translation type="unfinished">Opóźnienie przechwytywania niejawnego</translation>
+    </message>
+    <message>
+        <source>This delay is used when no delay was selected in
+the UI, it allows ksnip to hide before taking
+a screenshot. This value is not applied when
+ksnip was already minimized. Reducing this value
+can have the effect that ksnip&apos;s main window is
+visible on the screenshot.</source>
+        <translation type="unfinished">Opóźnienie jest używane, gdy nie wybrano opóźnienia w
+interfejsie użytkownika, pozwala ksnip ukryć się przed podjęciem
+zrzut ekranu. Ta wartość nie jest stosowana, gdy
+KSNIP był już zminimalizowany. Zmniejszenie tej wartości
+może mieć taki efekt, że głównym oknem KSNIP jest
+widoczne na zrzucie ekranu.</translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -824,6 +876,14 @@ Zmiana wymaga ponownego uruchomienia.</translation>
         <source>Clear Token</source>
         <translation>Wyczyść token</translation>
     </message>
+    <message>
+        <source>Upload title:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload description:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LoadImageFromFileOperation</name>
@@ -1060,6 +1120,22 @@ i wykonaniem zrzutu ekranu.</translation>
         <source>Image Files</source>
         <translation>Pliki obrazów</translation>
     </message>
+    <message>
+        <source>Save All</source>
+        <translation>Zapisz wszystko</translation>
+    </message>
+    <message>
+        <source>Close Window</source>
+        <translation>Zamknij okno</translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation>Przytnij</translation>
+    </message>
+    <message>
+        <source>OCR</source>
+        <translation>OCR</translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1091,6 +1167,10 @@ i wykonaniem zrzutu ekranu.</translation>
         <source>Rename</source>
         <translation>Zmień nazwę</translation>
     </message>
+    <message>
+        <source>Save All</source>
+        <translation>Zapisz wszystko</translation>
+    </message>
 </context>
 <context>
     <name>NewCaptureNameProvider</name>
@@ -1099,6 +1179,13 @@ i wykonaniem zrzutu ekranu.</translation>
         <translation>Zrzut z ekranu</translation>
     </message>
 </context>
+<context>
+    <name>OcrWindowCreator</name>
+    <message>
+        <source>OCR Window %1</source>
+        <translation>Okno OCR %1</translation>
+    </message>
+</context>
 <context>
     <name>PinWindow</name>
     <message>
@@ -1115,10 +1202,56 @@ i wykonaniem zrzutu ekranu.</translation>
     </message>
 </context>
 <context>
-    <name>PinWindowHandler</name>
+    <name>PinWindowCreator</name>
     <message>
-        <source>Pin Window %1</source>
-        <translation>Przypnij okno %1</translation>
+        <source>OCR Window %1</source>
+        <translation>Okno OCR %1</translation>
+    </message>
+</context>
+<context>
+    <name>PluginsSettings</name>
+    <message>
+        <source>Search Path</source>
+        <translation type="unfinished">Wyszukaj ścieżkę</translation>
+    </message>
+    <message>
+        <source>Default</source>
+        <translation>Domyślnie</translation>
+    </message>
+    <message>
+        <source>The directory where the plugins are located.</source>
+        <translation>Katalog, w którym znajdują się wtyczki.</translation>
+    </message>
+    <message>
+        <source>Browse</source>
+        <translation>Przeglądaj</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Nazwa</translation>
+    </message>
+    <message>
+        <source>Version</source>
+        <translation>Wersja</translation>
+    </message>
+    <message>
+        <source>Detect</source>
+        <translation>Wykryj</translation>
+    </message>
+    <message>
+        <source>Plugin Settings</source>
+        <translation>Ustawienia wtyczki</translation>
+    </message>
+    <message>
+        <source>Plugin location</source>
+        <translation>Lokalizacja wtyczki</translation>
+    </message>
+</context>
+<context>
+    <name>ProcessIndicator</name>
+    <message>
+        <source>Processing</source>
+        <translation>Przetwarzanie</translation>
     </message>
 </context>
 <context>
@@ -1243,6 +1376,10 @@ Not all image formats support the full range, JPEG does.</source>
         <translation>Podaj 0, aby uzyskać małe pliki skompresowane, 100 dla dużych plików nieskompresowanych.
 Nie wszystkie formaty obrazów obsługują pełny zakres, JPEG obsługuje pełny zakres.</translation>
     </message>
+    <message>
+        <source>Overwrite file with same name</source>
+        <translation>Zastąp plik o tej samej nazwie</translation>
+    </message>
 </context>
 <context>
     <name>ScriptUploaderSettings</name>
@@ -1363,6 +1500,14 @@ W przypadku pominięcia wszystko jest kopiowane.</translation>
         <source>FTP Uploader</source>
         <translation>Program do przesyłania FTP</translation>
     </message>
+    <message>
+        <source>Plugins</source>
+        <translation>Wtyczki</translation>
+    </message>
+    <message>
+        <source>Search Settings...</source>
+        <translation>Ustawienia wyszukiwania...</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1382,14 +1527,18 @@ W przypadku pominięcia wszystko jest kopiowane.</translation>
         <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
         <translation>Użyj klawiszy strzałek, jednocześnie naciskając ALT, aby przesunąć prawy dolny uchwyt.</translation>
     </message>
-    <message>
-        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
-        <translation>Potwierdź wybór naciskając ENTER/RETURN lub przerwij naciskając ESC.</translation>
-    </message>
     <message>
         <source>This message can be disabled via settings.</source>
         <translation>Ten komunikat można wyłączyć w ustawieniach.</translation>
     </message>
+    <message>
+        <source>Confirm selection by pressing ENTER/RETURN or mouse double-click anywhere.</source>
+        <translation>Potwierdź wybór, naciskając ENTER/RETURN lub klikając dwukrotnie myszką w dowolnym miejscu.</translation>
+    </message>
+    <message>
+        <source>Abort by pressing ESC.</source>
+        <translation>Przerwij, naciskając ESC.</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaSelectorInfoText</name>
@@ -1532,6 +1681,30 @@ Smaller number is more transparent.</source>
         <translation>Przezroczystość nie wybranego regionu w obszarze wycinania.
 Im mniejsza liczba, tym obszar bardziej przezroczysty.</translation>
     </message>
+    <message>
+        <source>Enable Snipping Area offset</source>
+        <translation>Włącz przesunięcie obszaru wycinania</translation>
+    </message>
+    <message>
+        <source>When enabled will apply the configured
+offset to the Snipping Area position which
+is required when the position is not
+correctly calculated. This is sometimes
+required with screen scaling enabled.</source>
+        <translation>Po włączeniu zostanie zastosowane skonfigurowane
+przesunięcie do pozycji Obszar wycinania, który
+jest wymagany, gdy pozycja nie jest
+poprawnie obliczona. Czasami jest to
+wymagane przy włączonym skalowaniu ekranu.</translation>
+    </message>
+    <message>
+        <source>X</source>
+        <translation>X</translation>
+    </message>
+    <message>
+        <source>Y</source>
+        <translation>Y</translation>
+    </message>
 </context>
 <context>
     <name>StickerSettings</name>
