@@ -102,6 +102,16 @@
         <source>Hide Main Window</source>
         <translation>Esconder Janela Principal</translation>
     </message>
+    <message>
+        <source>Global</source>
+        <translation>Global</translation>
+    </message>
+    <message>
+        <source>When enabled will make the shortcut
+available even when ksnip has no focus.</source>
+        <translation>Quando ativado fará o atalho disponível
+mesmo quando ksnip não tem o foco.</translation>
+    </message>
 </context>
 <context>
     <name>ActionsSettings</name>
@@ -197,6 +207,15 @@ being created, allowing changing settings.</source>
         <translation>Com esta opção ativa, o item fica selecionado após
 ser criado, permitindo alterar as configurações.</translation>
     </message>
+    <message>
+        <source>Show Controls Widget</source>
+        <translation>Mostrar widget de controles</translation>
+    </message>
+    <message>
+        <source>The Controls Widget contains the Undo/Redo,
+Crop, Scale, Rotate and Modify Canvas buttons.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ApplicationSettings</name>
@@ -284,10 +303,6 @@ Change requires ksnip restart to take effect.</source>
         <translation>Ativa a saída de depuração gravada no console.
 A mudança requer o reinício do ksnip para ter efeito.</translation>
     </message>
-    <message>
-        <source>Resize to content delay</source>
-        <translation>Atraso para redimensionar conteúdo</translation>
-    </message>
     <message>
         <source>Resizing to content is delay to allow the Window Manager to receive
 the new content. In case that the Main Windows is not adjusted correctly
@@ -296,6 +311,23 @@ to the new content, increasing this delay might improve the behavior.</source>
 um novo conteúdo, caso a janela principal não esteja ajustada corretamente
  ao novo conteúdo, aumentar esse atraso pode melhorar o comportamento.</translation>
     </message>
+    <message>
+        <source>Resize delay</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Temp Directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Temp directory used for storing temporary images that are
+going to be deleted after ksnip closes.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Browse</source>
+        <translation>Selecionar</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -705,6 +737,19 @@ quando a Janela Principal foi escondida ou minimizada.</translation>
         <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
         <translation>Escalar Wayland genérico (xdg-desktop-portal) para capturas de ecrã</translation>
     </message>
+    <message>
+        <source>Implicit capture delay</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This delay is used when no delay was selected in
+the UI, it allows ksnip to hide before taking
+a screenshot. This value is not applied when
+ksnip was already minimized. Reducing this value
+can have the effect that ksnip&apos;s main window is
+visible on the screenshot.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -824,6 +869,14 @@ Mudança requer reinicialização.</translation>
         <source>Clear Token</source>
         <translation>Limpar Token</translation>
     </message>
+    <message>
+        <source>Upload title:</source>
+        <translation>Ficheiro do envio</translation>
+    </message>
+    <message>
+        <source>Upload description:</source>
+        <translation>Descrição do envio</translation>
+    </message>
 </context>
 <context>
     <name>LoadImageFromFileOperation</name>
@@ -1060,6 +1113,22 @@ e captura de ecrã.</translation>
         <source>Image Files</source>
         <translation>Ficheiros de imagem</translation>
     </message>
+    <message>
+        <source>Save All</source>
+        <translation>Gravar tudo</translation>
+    </message>
+    <message>
+        <source>Close Window</source>
+        <translation>Fechar janela</translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OCR</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1091,6 +1160,10 @@ e captura de ecrã.</translation>
         <source>Rename</source>
         <translation>Renomear</translation>
     </message>
+    <message>
+        <source>Save All</source>
+        <translation>Gravar tudo</translation>
+    </message>
 </context>
 <context>
     <name>NewCaptureNameProvider</name>
@@ -1099,6 +1172,13 @@ e captura de ecrã.</translation>
         <translation>Imagem</translation>
     </message>
 </context>
+<context>
+    <name>OcrWindowCreator</name>
+    <message>
+        <source>OCR Window %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>PinWindow</name>
     <message>
@@ -1115,10 +1195,56 @@ e captura de ecrã.</translation>
     </message>
 </context>
 <context>
-    <name>PinWindowHandler</name>
+    <name>PinWindowCreator</name>
     <message>
-        <source>Pin Window %1</source>
-        <translation>Fixar janela %1</translation>
+        <source>OCR Window %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>PluginsSettings</name>
+    <message>
+        <source>Search Path</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Default</source>
+        <translation>Padrão</translation>
+    </message>
+    <message>
+        <source>The directory where the plugins are located.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Browse</source>
+        <translation>Selecionar</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Nome</translation>
+    </message>
+    <message>
+        <source>Version</source>
+        <translation>Versão</translation>
+    </message>
+    <message>
+        <source>Detect</source>
+        <translation>Detetar</translation>
+    </message>
+    <message>
+        <source>Plugin Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Plugin location</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ProcessIndicator</name>
+    <message>
+        <source>Processing</source>
+        <translation>A processar</translation>
     </message>
 </context>
 <context>
@@ -1243,6 +1369,10 @@ Not all image formats support the full range, JPEG does.</source>
         <translation>Indique 0 para obter pequenos ficheiros compactados, 100 para grandes ficheiros não compactados.
 Nem todos os formatos de imagem têm suporte a todos os intervalos, o JPEG suporta.</translation>
     </message>
+    <message>
+        <source>Overwrite file with same name</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ScriptUploaderSettings</name>
@@ -1363,6 +1493,14 @@ Quando omitido, tudo é copiado.</translation>
         <source>FTP Uploader</source>
         <translation>Enviador de FTP</translation>
     </message>
+    <message>
+        <source>Plugins</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Search Settings...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1382,14 +1520,18 @@ Quando omitido, tudo é copiado.</translation>
         <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
         <translation>Use as teclas de seta enquanto pressiona ALT para mover a alça inferior direita.</translation>
     </message>
-    <message>
-        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
-        <translation>Confirmar a seleção a pressionar ENTER/RETURN ou aborte a pressionar ESC.</translation>
-    </message>
     <message>
         <source>This message can be disabled via settings.</source>
         <translation>Esta mensagem pode ser desativada nas configurações.</translation>
     </message>
+    <message>
+        <source>Confirm selection by pressing ENTER/RETURN or mouse double-click anywhere.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Abort by pressing ESC.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaSelectorInfoText</name>
@@ -1532,6 +1674,26 @@ Smaller number is more transparent.</source>
         <translation>Alfa para região não selecionada na área retangular.
 O número menor é mais transparente.</translation>
     </message>
+    <message>
+        <source>Enable Snipping Area offset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When enabled will apply the configured
+offset to the Snipping Area position which
+is required when the position is not
+correctly calculated. This is sometimes
+required with screen scaling enabled.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>X</source>
+        <translation>X</translation>
+    </message>
+    <message>
+        <source>Y</source>
+        <translation>Z</translation>
+    </message>
 </context>
 <context>
     <name>StickerSettings</name>
