@@ -102,6 +102,15 @@
         <source>Hide Main Window</source>
         <translation>ප්‍රධාන කවුළුව සඟවන්න</translation>
     </message>
+    <message>
+        <source>Global</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When enabled will make the shortcut
+available even when ksnip has no focus.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ActionsSettings</name>
@@ -190,6 +199,15 @@ Changing color affects only new annotation areas.</source>
 being created, allowing changing settings.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Show Controls Widget</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The Controls Widget contains the Undo/Redo,
+Crop, Scale, Rotate and Modify Canvas buttons.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ApplicationSettings</name>
@@ -271,16 +289,29 @@ Docks visibility can be toggled with the Tab Key.</source>
 Change requires ksnip restart to take effect.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Resize to content delay</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Resizing to content is delay to allow the Window Manager to receive
 the new content. In case that the Main Windows is not adjusted correctly
 to the new content, increasing this delay might improve the behavior.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Resize delay</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Temp Directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Temp directory used for storing temporary images that are
+going to be deleted after ksnip closes.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Browse</source>
+        <translation type="unfinished">පිරික්සන්න</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -677,12 +708,25 @@ when the Main Window was hidden or minimize.</source>
         <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Implicit capture delay</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This delay is used when no delay was selected in
+the UI, it allows ksnip to hide before taking
+a screenshot. This value is not applied when
+ksnip was already minimized. Reducing this value
+can have the effect that ksnip&apos;s main window is
+visible on the screenshot.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
     <message>
         <source>Imgur History</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Imgur ඉතිහාසය</translation>
     </message>
     <message>
         <source>Close</source>
@@ -795,6 +839,14 @@ Changing requires restart.</source>
         <source>Clear Token</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Upload title:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload description:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LoadImageFromFileOperation</name>
@@ -1030,6 +1082,22 @@ and capturing screenshot.</source>
         <source>Image Files</source>
         <translation>අනුරූ ගොනු</translation>
     </message>
+    <message>
+        <source>Save All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Close Window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OCR</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1061,6 +1129,10 @@ and capturing screenshot.</source>
         <source>Rename</source>
         <translation>නැවත නම් කරන්න</translation>
     </message>
+    <message>
+        <source>Save All</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>NewCaptureNameProvider</name>
@@ -1069,6 +1141,13 @@ and capturing screenshot.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>OcrWindowCreator</name>
+    <message>
+        <source>OCR Window %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>PinWindow</name>
     <message>
@@ -1085,9 +1164,55 @@ and capturing screenshot.</source>
     </message>
 </context>
 <context>
-    <name>PinWindowHandler</name>
+    <name>PinWindowCreator</name>
     <message>
-        <source>Pin Window %1</source>
+        <source>OCR Window %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>PluginsSettings</name>
+    <message>
+        <source>Search Path</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Default</source>
+        <translation type="unfinished">පෙරනිමි</translation>
+    </message>
+    <message>
+        <source>The directory where the plugins are located.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Browse</source>
+        <translation type="unfinished">පිරික්සන්න</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished">නම</translation>
+    </message>
+    <message>
+        <source>Version</source>
+        <translation type="unfinished">අනුවාදය</translation>
+    </message>
+    <message>
+        <source>Detect</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Plugin Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Plugin location</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ProcessIndicator</name>
+    <message>
+        <source>Processing</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1208,6 +1333,10 @@ Filename can contain following wildcards:
 Not all image formats support the full range, JPEG does.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Overwrite file with same name</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ScriptUploaderSettings</name>
@@ -1325,6 +1454,14 @@ When omitted, everything is copied.</source>
         <source>FTP Uploader</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Plugins</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Search Settings...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1345,12 +1482,16 @@ When omitted, everything is copied.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
+        <source>This message can be disabled via settings.</source>
+        <translation>සැකසුම් හරහා මෙම පණිවිඩය අබල කළ හැකිය.</translation>
+    </message>
+    <message>
+        <source>Confirm selection by pressing ENTER/RETURN or mouse double-click anywhere.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>This message can be disabled via settings.</source>
-        <translation>සැකසුම් හරහා මෙම පණිවිඩය අබල කළ හැකිය.</translation>
+        <source>Abort by pressing ESC.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1476,6 +1617,26 @@ on the snipping area.</source>
 Smaller number is more transparent.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Enable Snipping Area offset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When enabled will apply the configured
+offset to the Snipping Area position which
+is required when the position is not
+correctly calculated. This is sometimes
+required with screen scaling enabled.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>X</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Y</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StickerSettings</name>
@@ -1584,7 +1745,7 @@ service when such exists. Change requires restart to take effect.</source>
     </message>
     <message>
         <source>Image Files</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">අනුරූ ගොනු</translation>
     </message>
 </context>
 <context>
