@@ -102,6 +102,16 @@
         <source>Hide Main Window</source>
         <translation>Приховати головне вікно</translation>
     </message>
+    <message>
+        <source>Global</source>
+        <translation>Загальне</translation>
+    </message>
+    <message>
+        <source>When enabled will make the shortcut
+available even when ksnip has no focus.</source>
+        <translation>Якщо позначено, скороченням можна 
+буде користуватися, навіть якщо ksnip не перебуває у фокусі.</translation>
+    </message>
 </context>
 <context>
     <name>ActionsSettings</name>
@@ -198,6 +208,16 @@ being created, allowing changing settings.</source>
         <translation>Якщо цей пункт буде позначено, програма позначатиме елемент
 після його створення, надаючи змогу змінити його параметри.</translation>
     </message>
+    <message>
+        <source>Show Controls Widget</source>
+        <translation>Показати віджет керування</translation>
+    </message>
+    <message>
+        <source>The Controls Widget contains the Undo/Redo,
+Crop, Scale, Rotate and Modify Canvas buttons.</source>
+        <translation>На віджеті керування розташовано кнопки Скасування/Повторення, 
+Обрізання, Масштабування, Обертання та Зміни полотна.</translation>
+    </message>
 </context>
 <context>
     <name>ApplicationSettings</name>
@@ -285,10 +305,6 @@ Change requires ksnip restart to take effect.</source>
         <translation>Вмикає діагностичне виведення до консолі.
 Для набуття змінами чинності слід перезапустити ksnip.</translation>
     </message>
-    <message>
-        <source>Resize to content delay</source>
-        <translation>Затримка зміни розмірів до вмісту</translation>
-    </message>
     <message>
         <source>Resizing to content is delay to allow the Window Manager to receive
 the new content. In case that the Main Windows is not adjusted correctly
@@ -297,6 +313,24 @@ to the new content, increasing this delay might improve the behavior.</source>
 керування вікнами отримання нового вмісту. Якщо головне вікно не
 коригується за новим вмістом, збільшення затримки може поліпшити ситуацію.</translation>
     </message>
+    <message>
+        <source>Resize delay</source>
+        <translation>Затримка зміни розмірів</translation>
+    </message>
+    <message>
+        <source>Temp Directory</source>
+        <translation>Тимчасовий каталог</translation>
+    </message>
+    <message>
+        <source>Temp directory used for storing temporary images that are
+going to be deleted after ksnip closes.</source>
+        <translation>Тимчасовий каталог використовують для зберігання тимчасових зображень, 
+які буде вилучено після завершення роботи ksnip.</translation>
+    </message>
+    <message>
+        <source>Browse</source>
+        <translation>Вибрати</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -706,6 +740,24 @@ when the Main Window was hidden or minimize.</source>
         <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
         <translation>Масштабовані загальні знімки вікон Wayland (xdg-desktop-portal)</translation>
     </message>
+    <message>
+        <source>Implicit capture delay</source>
+        <translation>Неявна затримка захоплення</translation>
+    </message>
+    <message>
+        <source>This delay is used when no delay was selected in
+the UI, it allows ksnip to hide before taking
+a screenshot. This value is not applied when
+ksnip was already minimized. Reducing this value
+can have the effect that ksnip&apos;s main window is
+visible on the screenshot.</source>
+        <translation>Цю затримку буде використано, якщо затримку не було 
+вибрано в інтерфейсі користувача. Ця затримка надає змогу 
+приховувати ksnip перед створення знімка. Значення не буде 
+застосовано, якщо ksnip вже мінімізовано. Надмірне зменшення цього 
+значення може призвести до того, що вікно ksnip з&apos;явиться на 
+знімку.</translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -825,6 +877,14 @@ Changing requires restart.</source>
         <source>Clear Token</source>
         <translation>Вилучити жетон</translation>
     </message>
+    <message>
+        <source>Upload title:</source>
+        <translation>Заголовок вивантаженого:</translation>
+    </message>
+    <message>
+        <source>Upload description:</source>
+        <translation>Опис вивантаженого:</translation>
+    </message>
 </context>
 <context>
     <name>LoadImageFromFileOperation</name>
@@ -1061,6 +1121,22 @@ and capturing screenshot.</source>
         <source>Image Files</source>
         <translation>файли зображень</translation>
     </message>
+    <message>
+        <source>Save All</source>
+        <translation>Зберегти усе</translation>
+    </message>
+    <message>
+        <source>Close Window</source>
+        <translation>Закрити вікно</translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation>Вирізати</translation>
+    </message>
+    <message>
+        <source>OCR</source>
+        <translation>Розпізнати текст</translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1092,6 +1168,10 @@ and capturing screenshot.</source>
         <source>Rename</source>
         <translation>Перейменувати</translation>
     </message>
+    <message>
+        <source>Save All</source>
+        <translation>Зберегти усе</translation>
+    </message>
 </context>
 <context>
     <name>NewCaptureNameProvider</name>
@@ -1100,6 +1180,13 @@ and capturing screenshot.</source>
         <translation>Захопити</translation>
     </message>
 </context>
+<context>
+    <name>OcrWindowCreator</name>
+    <message>
+        <source>OCR Window %1</source>
+        <translation>Вікно розпізнавання тексту %1</translation>
+    </message>
+</context>
 <context>
     <name>PinWindow</name>
     <message>
@@ -1116,10 +1203,56 @@ and capturing screenshot.</source>
     </message>
 </context>
 <context>
-    <name>PinWindowHandler</name>
+    <name>PinWindowCreator</name>
     <message>
-        <source>Pin Window %1</source>
-        <translation>Пришпилити вікно %1</translation>
+        <source>OCR Window %1</source>
+        <translation>Вікно розпізнавання тексту %1</translation>
+    </message>
+</context>
+<context>
+    <name>PluginsSettings</name>
+    <message>
+        <source>Search Path</source>
+        <translation>Шлях для пошуку</translation>
+    </message>
+    <message>
+        <source>Default</source>
+        <translation>Типове</translation>
+    </message>
+    <message>
+        <source>The directory where the plugins are located.</source>
+        <translation>Каталог, у якому зберігаються додатки.</translation>
+    </message>
+    <message>
+        <source>Browse</source>
+        <translation>Вибрати</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Назва</translation>
+    </message>
+    <message>
+        <source>Version</source>
+        <translation>Версія</translation>
+    </message>
+    <message>
+        <source>Detect</source>
+        <translation>Виявити</translation>
+    </message>
+    <message>
+        <source>Plugin Settings</source>
+        <translation>Параметри додатків</translation>
+    </message>
+    <message>
+        <source>Plugin location</source>
+        <translation>Розташування додатків</translation>
+    </message>
+</context>
+<context>
+    <name>ProcessIndicator</name>
+    <message>
+        <source>Processing</source>
+        <translation>Обробка</translation>
     </message>
 </context>
 <context>
@@ -1244,6 +1377,10 @@ Not all image formats support the full range, JPEG does.</source>
         <translation>Вкажіть 0 для отримання малих стиснених файлів або 100 для отримання великих файлів без стискання.
 Повний діапазон коефіцієнтів стискання передбачено не усіма форматами, але його підтримку передбачено у JPEG.</translation>
     </message>
+    <message>
+        <source>Overwrite file with same name</source>
+        <translation>Перезаписати файл із тією самою назвою</translation>
+    </message>
 </context>
 <context>
     <name>ScriptUploaderSettings</name>
@@ -1364,6 +1501,14 @@ When omitted, everything is copied.</source>
         <source>FTP Uploader</source>
         <translation>Вивантажувач FTP</translation>
     </message>
+    <message>
+        <source>Plugins</source>
+        <translation>Додатки</translation>
+    </message>
+    <message>
+        <source>Search Settings...</source>
+        <translation>Параметри пошуку…</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1383,14 +1528,18 @@ When omitted, everything is copied.</source>
         <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
         <translation>Скористайтеся клавішами зі стрілками разом із Alt для пересування нижнього правого кута.</translation>
     </message>
-    <message>
-        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
-        <translation>Підтвердьте позначення натисканням Enter/Return або скасуйте дію натисканням Esc.</translation>
-    </message>
     <message>
         <source>This message can be disabled via settings.</source>
         <translation>Це повідомлення можна вимкнути у параметрах програми.</translation>
     </message>
+    <message>
+        <source>Confirm selection by pressing ENTER/RETURN or mouse double-click anywhere.</source>
+        <translation>Підтвердьте вибір натисканням клавіші Enter або подвійним клацанням кнопкою миші у довільному місці екрана.</translation>
+    </message>
+    <message>
+        <source>Abort by pressing ESC.</source>
+        <translation>Перервати дію можна натисканням Esc.</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaSelectorInfoText</name>
@@ -1534,6 +1683,30 @@ Smaller number is more transparent.</source>
         <translation>Рівень прозорості для непозначеної ділянки області обрізання.
 Менше значення — прозоріша ділянка.</translation>
     </message>
+    <message>
+        <source>Enable Snipping Area offset</source>
+        <translation>Увімкнути відступ області вирізання</translation>
+    </message>
+    <message>
+        <source>When enabled will apply the configured
+offset to the Snipping Area position which
+is required when the position is not
+correctly calculated. This is sometimes
+required with screen scaling enabled.</source>
+        <translation>Якщо позначено, буде застосовано налаштований 
+відступ області вирізання, який потрібен, якщо 
+розташування області обчислено неправильно. 
+Такий відступ іноді потрібен, якщо увімкнено 
+масштабування екрана.</translation>
+    </message>
+    <message>
+        <source>X</source>
+        <translation>X</translation>
+    </message>
+    <message>
+        <source>Y</source>
+        <translation>Y</translation>
+    </message>
 </context>
 <context>
     <name>StickerSettings</name>
